@@ -32,9 +32,9 @@
 #'
 #' @return A vector of unique identifiers (UID). If a taxon is not found NA.
 #' If more than one UID is found the function asks for user input (if ask = TRUE),
-#' otherwise returns NA. Comes with an attribute \emph{match} to investigate the
-#' reason for NA (either 'not found', 'found' or if ask = FALSE 'multi match').
-#' If \code{ask=FALSE} and \code{rows} does not equal NA, then a data.frame is
+#' otherwise returns \code{NA}. Comes with an attribute \emph{match} to investigate the
+#' reason for NA (either 'not found', 'found' or if \code{ask = FALSE} 'NA due to ask=FALSE').
+#' If \code{ask=FALSE} and \code{rows} does not equal \code{NA}, then a data.frame is
 #' given back, but not of the uid class, which you can't pass on to other functions
 #' as you normally can.
 #'
@@ -159,19 +159,19 @@ get_uid <- function(sciname, ask = TRUE, verbose = TRUE, rows = NA, modifier = N
     if (!is.null(rank_query)) url <- paste0(url, sprintf(" AND %s[Rank]", rank_query))
     url <- URLencode(url)
     errors_to_catch <- c("Could not resolve host: eutils.ncbi.nlm.nih.gov")
-    xml_result <- xmlParse(repeat_until_it_works(catch = errors_to_catch, url = url, ...))
+    xml_result <- xml2::read_xml(repeat_until_it_works(catch = errors_to_catch, url = url))
 
     # NCBI limits requests to three per second
     Sys.sleep(0.33)
-    uid <- xpathSApply(xml_result, "//IdList/Id", xmlValue)
+    uid <- xml2::xml_text(xml2::xml_find_all(xml_result, "//IdList/Id"))
     if (length(uid) == 0) { # if taxon name is not found
       uid <- NA
     } else {
       uid <- sub_vector(uid, rows)
+      att <- 'found'
     }
-    att <- 'found'
     # not found on ncbi
-    if (length(uid) == 0) {
+    if (length(uid) == 0 || is.na(uid)) {
       mssg(verbose, "Not found. Consider checking the spelling or alternate classification")
       uid <- NA
       att <- 'not found'
@@ -184,7 +184,7 @@ get_uid <- function(sciname, ask = TRUE, verbose = TRUE, rows = NA, modifier = N
         url <- paste(baseurl, ID, sep = "&")
         errors_to_catch <- c("Could not resolve host: eutils.ncbi.nlm.nih.gov")
         tt <- repeat_until_it_works(catch = errors_to_catch, url = url, ...)
-        ttp <- xmlTreeParse(tt, useInternalNodes = TRUE)
+        ttp <- xml2::read_xml(tt)
         df <- parse_ncbi(ttp)
         rownames(df) <- 1:nrow(df)
 
@@ -237,10 +237,6 @@ get_uid <- function(sciname, ask = TRUE, verbose = TRUE, rows = NA, modifier = N
   add_uri(out, 'http://www.ncbi.nlm.nih.gov/taxonomy/%s')
 }
 
-get_content <- function(url, ...) {
-  content(GET(url = url, ...))
-}
-
 repeat_until_it_works <- function(catch, url, max_tries = 3, wait_time = 10, verbose = TRUE, ...) {
   error_handler <- function(e) {
     if (e$message %in% catch) {
@@ -251,7 +247,7 @@ repeat_until_it_works <- function(catch, url, max_tries = 3, wait_time = 10, ver
     }
   }
   for (count in 1:max_tries) {
-    output <- tryCatch(content(GET(url = url, ...), "text"), error = error_handler)
+    output <- tryCatch(con_utf8(GET(url = url, ...)), error = error_handler)
     if (!is.na(output)) return(output)
     Sys.sleep(wait_time * count)
   }
@@ -297,9 +293,9 @@ make_uid <- function(x, check=TRUE) make_generic(x, 'http://www.ncbi.nlm.nih.gov
 check_uid <- function(x){
   url <- "http://eutils.ncbi.nlm.nih.gov/entrez/eutils/esummary.fcgi?db=taxonomy&id="
   res <- GET(paste0(url, x))
-  tt <- content(res)
-  tryid <- xpathSApply(tt, "//Id", xmlValue)
-  identical(x, tryid)
+  tt <- xml2::read_xml(con_utf8(res))
+  tryid <- xml2::xml_text(xml2::xml_find_all(tt, "//Id"))
+  identical(as.character(x), tryid)
 }
 
 
@@ -313,17 +309,17 @@ get_uid_help <- function(sciname, verbose, rows){
   mssg(verbose, "\nRetrieving data for taxon '", sciname, "'\n")
   url <- paste("http://eutils.ncbi.nlm.nih.gov/entrez/eutils/esearch.fcgi?db=taxonomy&term=",
                gsub(" ", "+", sciname), sep = "")
-  xml_result <- xmlParse(content(GET(url), "text"))
+  xml_result <- xml2::read_xml(con_utf8(GET(url)))
   Sys.sleep(0.33)
-  uid <- xpathSApply(xml_result, "//IdList/Id", xmlValue)
+  uid <- xml_text(xml_find_all(xml_result, "//IdList/Id"))
   if (length(uid) == 0) {
     NULL
   } else {
     baseurl <- "http://eutils.ncbi.nlm.nih.gov/entrez/eutils/esummary.fcgi?db=taxonomy"
     ID <- paste("ID=", paste(uid, collapse = ","), sep = "")
     url <- paste(baseurl, ID, sep = "&")
-    tt <- content(GET(url), "text")
-    ttp <- xmlTreeParse(tt, useInternalNodes = TRUE)
+    tt <- con_utf8(GET(url))
+    ttp <- xml2::read_xml(tt)
     df <- parse_ncbi(ttp)
     sub_rows(df, rows)
   }
@@ -333,9 +329,9 @@ parse_ncbi <- function(x) {
   mget <- c("Status", "Rank", "Division", "ScientificName",
             "CommonName", "TaxId", "Genus", "Species", "Subsp", "ModificationDate")
   nget <- paste0('Item[@Name="', mget, "\"]")
-  nodes <- getNodeSet(x, "//DocSum")
+  nodes <- xml_find_all(x, "//DocSum")
   tmp <- taxize_ldfast(lapply(nodes, function(z) {
-    data.frame(setNames(sapply(nget, function(w) xpathApply(z, w, xmlValue)), tolower(mget)), stringsAsFactors = FALSE)
+    data.frame(as.list(setNames(sapply(nget, function(w) xml_text(xml_find_all(z, w))), tolower(mget))), stringsAsFactors = FALSE)
   }))
   rename(tmp, c('taxid' = 'uid'))
 }
